R_fxn: Ration function

Description Usage Arguments

View source: R/growth_fuctions.R

Description

Calculate the ration available to a fish given a consumption rate, foraging time, and prey dry mass. Available ration is relative to the temperature- and mass-dependent ration that maximizes growth. When ration >1 fish are satiated and food is not limiting to growth; when ration <1 food is limiting.

Usage

1
2
3
4
5
6
7
8
R_fxn(
  foraging_time = FORAGING_TIME,
  consumption_rate,
  dry_mass = DRY_MASS,
  Temperature,
  M0,
  ...
)

Arguments

foraging_time

time (in minutes) a fish forages. Default = 360

consumption_rate

calculated with typeII function

dry_mass

dry mass (in ___) of prey

Temperature

water temperature (in C)

M0

initial fish mass (in grams)

...

coreyphillis/fisHeat documentation built on Dec. 31, 2020, 10:07 p.m.