Description Usage Arguments Value
View source: R/growth_fuctions.R
Function to create fish population with specified abundance and fork length distribution.
1 2 3 4 5 6 7 |
nfish |
number of fish in the population |
init_fl |
Named list ('min', 'max', 'mode') of initial fork lengths when distribution of fish for fl_distribution = 'triangle' (default) |
fl_distribution |
'triangle' uses rtriangle() distribution. 'discrete' creates three discrete size classes ('small', 'medium', 'large') according to psizeclass |
psizeclass |
proportion in each size class when fl_distribution = 'discrete' |
... |
list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.