Description Usage Arguments Value
View source: R/growth_fuctions.R
Calculate the new mass of a fish from its old mass after a specficed number of days, prey density, and temperature
1 | newmass_fxn(prey_density, temperature, old_mass, day)
|
prey_density |
prey_density in individuals per liter |
temperature |
water temperature in degrees C |
old_mass |
initial mass of fish in grams |
day |
day on which mass should be calculated |
Vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.