View source: R/growth_fuctions.R
Calculate the ration available to a fish given a consumption rate, foraging time, and prey dry mass. Available ration is relative to the temperature- and mass-dependent ration that maximizes growth. When ration >1 fish are satiated and food is not limiting to growth; when ration <1 food is limiting.
1 2 3 4 5 6 7 8 |
foraging_time |
time (in minutes) a fish forages. Default = 360 |
consumption_rate |
calculated with typeII function |
dry_mass |
dry mass (in ___) of prey |
Temperature |
water temperature (in C) |
M0 |
initial fish mass (in grams) |
... |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.